package Kitten;

use strict;
use warnings;
use CGI::Application::Pluggable qw/
    TT
    LogDispatch
    DebugScreen
    Session
    Redirect
    Forward
    Config::YAML
    Stash
/;

use Kitten::Strage::DBIC::Schema;
use Kitten::Util;

our $VERSION = '0.02';

sub cgiapp_init {
    my $self = shift;

    $self->config_file('config.yaml');

    $self->session_config(
         CGI_SESSION_OPTIONS => [
             "driver:File",
             $self->query,
             {Directory=>$self->config_param->{Session}->{dir}}
         ],
         COOKIE_PARAMS => {
             -expires => '',
             -path    => '/',
         },
         SEND_COOKIE => 1,
    );

    $self->log_config(
        LOG_DISPATCH_MODULES => [
            {
                module    => 'Log::Dispatch::File',
                name      => 'info',
                filename  => $self->config_param->{Logging}->{dir},
                min_level => 'info',
                mode      => 'append',
                append_newline => 1,
            },
        ],
    );

    $self->tt_include_path($self->config_param->{Template}->{dir});
}

sub cgiapp_prerun {
    shift->header_props( -charset => 'utf8',);
}

sub teardown {
    my $self = shift;
    Kitten::Util::cleanSession($self);
}

sub do_error {
    shift->tt_process('error.tt');
}

1;

__END__
=head1 NAME

Kitten - Lite Memo Tool powerd by CGI::Application.

=head1 VERSION

This documentation refers to Kitten version 0.02

=head1 SEE ALSO

http://nekokak.jf.land.to/wiki/wiki.cgi/sub?page=Perl%2FKitten

=head1 DEPENDENCIES

L<CGI::Application>
L<CGI::Application::Pluggable>
L<CGI::Application::Plugin::TT>
L<CGI::Application::Plugin::LogDispatch>
L<CGI::Application::Plugin::DebugScreen>
L<CGI::Application::Plugin::Session>
L<CGI::Application::Plugin::Redirect>
L<CGI::Application::Plugin::Forward>
L<CGI::Application::Plugin::Config::YAML>
L<CGI::Application::Plugin::Stash>
L<DBIx::Class>
L<DBIx::Class::Schema::Loader>
L<Data::Page::Navigation>
L<XML::FeedPP>
L<XML::TreePP>
L<File::Finder>

=head1 AUTHOR

Atsushi Kobayashi, E<lt>nekokak@cpan.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2006 by Atsushi Kobayashi (E<lt>nekokak@cpan.orgE<gt>). All rights reserved.

This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself. See L<perlartistic>.

=cut
