package Kitten::Strage::DBIC::Schema;

use strict;
use warnings;
use base qw/DBIx::Class::Schema::Loader/;

__PACKAGE__->load_from_connection(
    dsn => 'dbi:SQLite:kitten.db',
);

use Kitten::Util;
use POSIX "strftime";
use Data::Page::Navigation;

sub memo_search {
    my $self = shift;
    my $cap  = shift;

    my $q    = $cap->query;
    my $page = $q->param('page') ? $q->param('page') : 1;

    eval {
        $cap->stash->{memo} = __PACKAGE__->resultset('Memo')->search(
            {
                memo => {'like', '%'.&Kitten::Util::escapeDB($q->param('memo')).'%'}
            },
            {
                page     => $page,
                row      => 10,
                order_by => 'id DESC',
            }
        );
    };
    if ( $@ ) {
        $cap->log->info($@);
        die;
    }

    return;
}

sub tags_search {
    my $self = shift;
    my $cap  = shift;

    my $q    = $cap->query;
    my $page = $q->param('page') ? $q->param('page') : 1;

    eval {
        $cap->stash->{memo} = __PACKAGE__->resultset('Memo')->search(
            {
                tags => &Kitten::Util::escapeDB($q->param('tags')),
            },
            {
                page     => $page,
                row      => 10,
                order_by => 'id DESC',
            }
        );
    };
    if ( $@ ) {
        $cap->log->info($@);
        die;
    }

    return;
}

sub memo_create {
    my $self = shift;
    my $cap  = shift;

    my $q = $cap->query;
    my $id;
    eval {
        $id = __PACKAGE__->resultset('Memo')->create(
            {
                title => $q->param('title'),
                memo  => $q->param('memo'),
                date  => strftime("%Y/%m/%d %H:%M:%S", localtime()),
                tags  => $q->param('tags'),
            },
        );
    };

    if ( $@ ) {
        $cap->log->info($@);
        die;
    }
    $cap->stash->{last_insert_id} = $id->last_insert_id;

    unless ( $cap->stash->{last_insert_id} ) {
        $cap->log->info('Can not insert new memo');
        die;
    }

    return;
}

sub memo_edit {
    my $self = shift;
    my $cap  = shift;

    my $q = $cap->query;
    my $memo;
    eval {
        $memo = __PACKAGE__->resultset('Memo')->find(&Kitten::Util::escapeDB($cap->query->param('id')));
    };
    if ( $@ ) {
        $cap->log->info($@);
        die;
    }

    $memo->title($q->param('title')) if $q->param('title') && $q->param('title') ne $memo->title;
    $memo->memo( $q->param('memo') ) if $q->param('memo')  && $q->param('memo')  ne $memo->memo;
    $memo->tags( $q->param('tags') ) if $q->param('tags')  && $q->param('tags')  ne $memo->tags;

    eval {
        $memo->update;
    };
    if ( $@ ) {
        $cap->log->info($@);
        die;
    }
    return;
}

sub memo_del {
    my $self = shift;
    my $cap  = shift;

    eval {
        my $m = __PACKAGE__->resultset('Memo')->find(id => &Kitten::Util::escapeDB($cap->query->param('id')));
        $m->delete;
    };
    if ( $@ ) {
        $cap->log->info($@);
        die;
    }
    return;
}


sub memo_get {
    my $self = shift;
    my $cap  = shift;

    eval {
        $cap->stash->{memo} = __PACKAGE__->resultset('Memo')->search({id => &Kitten::Util::escapeDB($cap->query->param('id'))},)->first;
    };
    if ( $@ ) {
        $cap->log->info($@);
        die;
    }

    return;
}

sub memo_list {
    my $self = shift;
    my $cap  = shift;

    my $q = $cap->query;
    my $page = $q->param('page') ? $q->param('page') : 1;

    eval {
        $cap->stash->{memo} = __PACKAGE__->resultset('Memo')->search(
            {},
            {
                page => $page,
                row  => 10,
                order_by => 'id DESC'
            }
        );
    };
    if ( $@ ) {
        $cap->log->info($@);
        die;
    }

    return;
}

sub user_get {
    my $self = shift;
    my $cap  = shift;

    my $q = $cap->query;
    my $passwd = $self->_passwd($q);

    my $count;
    eval {
        $count = __PACKAGE__->resultset('User')->count(
            {
                name   => &Kitten::Util::escapeDB($q->param('user')),
                passwd => &Kitten::Util::escapeDB($passwd),
            }
        );
    };
    if ( $@ ) {
        $cap->log->info($@);
        die;
    }

    return $count;
}

sub _passwd {
    my $self = shift;
    my $q    = shift;

    my $passwd = &Kitten::Util::passwd($q->param('passwd'),$q->param('user'));
    return $passwd;
}

1;

